# Chess.com Python API

[<img src="https://images.chesscomfiles.com/uploads/v1/blog/291978.333e4ddb.668x375o.576e795e2298.png" width="300" align="center"/>](image.png)

Unofficial Chess.com Python API and toolkit. (**Work In Progress**)

This Python API is a wrapper to the [PubAPI](https://www.chess.com/news/view/published-data-api) (a read-only REST API that responds with JSON-LD data).

## Install

Install from PyPi:

```
python3 -m pip install chesscom
```

Install locally

```
git clone git@github.com:jeffreywardman/chesscom.git
cd chesscom
python3 -m pip install -e .
```

## To Do

- Plot by piece type
- Plot piece coverage
- Plot attacked pieces
- Create game GIFs
- Documentation
- Automated versioning and unit tests (within docker container)

## Final Comment

Feel free to add me (jeffreywardman) on chess.com so we can play sometime!
